;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
#|
ABOUT RAINBOW TROUT BIOMETRIC DATA

http://seattlecentral.edu/qelp/sets/023/023.html

    Rainbow trout taken from 4 different localities along the Spokane River
(eastern on) during July, August and October of 1999 were analyzed for heavy
metals ashington State Department of Ecology. As part of this study, the length
(in Rainbow trout show an exponential relationship between length and
weight. maller (younger) fish are relatively long and skinny, whereas larger
(older) sh are much more stout. This type of growth sequence is very common
among plants and animals; humans show the same kind of growth behavior.

    The good fit of an exponential model to the data could be utilized to
eliminate weighing the fish; just measure the length, and calculate the weight
from the function.

Reference: Johnson, A. (2000), Results from Analyzing Metals in 1999 Spokane
River Fish and Crayfish Samples; Washington State Dept. of Ecology report.

Web Site: http://www.ecy.wa.gov/biblio/0003017.html 
|#
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(def a '(457 855 405 715 455 975 460 895 335 472 365 540 390 660 368 581 385
609 360 557 346 433 438 840 392 623 324 387 360 479 413 754 276 235 387 538 345
438 395 584 326 353 270 209 359 476 347 432 259 202 247 184 280 248 265 223 309
392 338 460 334 406 332 383 324 353 337 363 343 390 318 340 305 303 335 410 317
335 351 506 368 605 502 1300))
(mvsq '(length weight) (transpose (split-list a 2)))

(def reg
     (regress
      (list (ln length))
      (ln weight)
      )
     )

(def coefficients (send reg :coef-estimates))

;; initial values (solutions of linearization)
(setq
 alpha (exp (first coefficients))
 beta (second coefficients)
 nreg (nreg-model
       (lambda(theta)
	 (let (
	       (alpha (elt theta 0))
	       (beta (elt theta 1))
	       )
	   (* alpha (^ length beta))
	   )
	 )
       weight
       (list alpha beta)
       )
 nreg-coefficients (send nreg :coef-estimates)
 )

(defun f(x alpha beta)
  (* alpha (^ x beta))
  )
(derfunc fpa f alpha)
(derfunc fpb f beta)

;; find parameters for weight versus length:
(def runs 6)
(dotimes (i runs)
  (let* (
	 (n (length length))
	 (alphas (repeat alpha n))
	 (betas (repeat beta n))
	 (estimates (mapcar #'f length alphas betas))
	 reg new-coefs coefs
	 )
    (setq reg (regress (list
			(mapcar #'fpa length alphas betas)
			(mapcar #'fpb length alphas betas)
			)
		       (-
			weight
			estimates
			)
		       :intercept nil
		       :print t
		       )
	  new-coefs (send reg :coef-estimates)
	  coefs (+ (list alpha beta) new-coefs)
	  alpha (first coefs)
	  beta (second coefs)
	  )
    (print (list alpha beta))
    )
  )

(xgobips
 "nreg-stuff.ps"
 1  ;; red   level 
 0  ;; green
 0  ;; blue
 length weight
 :glyph-type 2
 :glyph-size 5
 :morelines (list (list 0 0 1 
			(rseq (min length)  (max length) 1000)
			(mapcar 
			 (lambda(x) (* alpha (^ x beta)))
			 (rseq (min length)  (max length) 1000))
			"lndashed"))
 :title "Weight versus length for Rainbow Trout"
 :xlabel "Length"
 :ylabel "Weight"
 :x-axis t
 )






